@@ -90,7 +90,7 @@ class dyn_obj:
         self.body = ref_frame(obj.name+'_body', self.pa_axes.ob, anim)
         
         obj.parent = self.body.ob
-        obj.scale = (scale, scale, scale)
+        obj.scale = (self.scale, self.scale, self.scale)
 
         self.body.static_6DOF(-self.quat, None, None, None)
 
